@@ -1,5 +1,5 @@
 /*
-% Copyright (C) 2003 - 2011 GraphicsMagick Group
+% Copyright (C) 2003 - 2012 GraphicsMagick Group
 % Copyright (C) 2002 ImageMagick Studio
 %
 % This program is covered by multiple licenses, which are described in
@@ -1553,13 +1553,17 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
 
       image=AllocateImage(clone_info);
       if (image == (Image *) NULL)
-        return(False);
+        {
+          DestroyImageInfo(clone_info);
+          return((Image *) NULL);
+        }
       (void) strlcpy(image->filename,clone_info->filename,MaxTextExtent);
       status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
       if (status == False)
         {
+          DestroyImageInfo(clone_info);
           DestroyImage(image);
-          return(False);
+          return((Image *) NULL);
         }
       if (!BlobIsSeekable(image))
         {
@@ -2168,7 +2172,7 @@ MagickExport unsigned int WriteImage(const ImageInfo *image_info,Image *image)
 		      DestroyImageInfo(clone_info);
 		      return(False);
 		    }
-		  (void) strlcpy(image->filename,tempfile,sizeof(tempfile));
+		  (void) strlcpy(image->filename,tempfile,sizeof(image->filename));
 		}
 	      else
 		{
